#include "testApp.h"


//--------------------------------------------------------------
void testApp::setup(){	 
	ofBackground(255,255,255);	
	
	isSetup = false;
	
	serial.enumerateDevices();
	
	XML.loadFile("device.xml");
			
	int device = XML.getValue("DEVICEID", 0);

	//----------------------------------- note:
	isSetup = serial.setup(device, 9600);	// < this should be set
										// to whatever com port
										// your serial device is 
										// connected to.  
										// (ie, COM4 on a pc, dev/tty.... on a mac)
										// arduino users check in arduino app....
	
	
	VID.loadMovie("scrub.mov");
	VID.play();

	VID2.loadMovie("trigger.mov");
	VID2.play();
	VID2.setSpeed(0);
	
	full = 0;
	
	bMoviePlay = false;
	ofSetVerticalSync(true);
	
	TTF.loadFont("DIN.otf", 28); 
	
	posVal = 0;
	
	memset(values, 0, 640 * sizeof(float));
	
	state = 0;
		
}

//--------------------------------------------------------------
void testApp::update(){

	// (1) write the letter "!" to serial - 
	//this will tell the arduino we ready to get data:
	serial.writeByte('!');
		
	// (2) read
	// we try to read 2 bytes

	//clear our variables
	int nTimesRead  = 0;
	int nBytesRead  = 0;
	int nRead		= 0;  // a temp variable to keep count per read
	
	//we are going to read a 0 - 1024 number as two bytes
	//we need a buffer to store the two bytes and a second 
	//buffer with space for the terminating zero byte 
	unsigned char bytesReturned[2];
	unsigned char bytesReadString[3];
	

	//clear our buffers
	memset(bytesReadString, 0, 3);
	memset(bytesReturned, 0, 2);
			
	//we read as much as possible so we make sure we get the newest data
	while( (nRead = serial.readBytes( bytesReturned, 2)) > 0){
		nTimesRead++;	
		nBytesRead = nRead;
	}

	//if we have got both bytes
	if( nBytesRead == 2){
	
		//lets update our buffer
		memcpy(bytesReadString, bytesReturned, 2);
		
		//we need to put the bytes back into an int
		int num = ( (unsigned char)bytesReadString[1] << 8 | (unsigned char)bytesReadString[0] );
		
		//the number as a string
		message = "1st byte:"+ ofToString( (unsigned char)bytesReadString[0] ) + "  2nd byte:" + ofToString( (unsigned char)bytesReadString[1] ) +" = "+ofToString(num);
		
		valueIn = num;
		
		//smooth the value a little - take 25% of the incomming value
		pct *= 0.75;
		pct += 0.25 * ((float)num/1023.0);
		
		//this is hack so the movie doesn't loop around
		if(pct < 0.001) pct = 0.001;
		if(pct > 0.999) pct = 0.999;
		
		normalizedValue = pct;
		smoothedValue	= pct * 1023;
		
		//set the 1st video position based on 
		//the value coming in
		VID.setPosition(pct);
		
		//for our value graph
		if(posVal >= 640) posVal -= 640;
		values[posVal] = normalizedValue;
		posVal++;
		
		
		//for our trigger video
		
		//our high trigger value for the video
		if(smoothedValue > 900){
			//only trigger the video once
			if( state == 0 ){
				state = 1;
				VID2.setPosition(0);
				VID2.setSpeed(1);
			}
		}else{
			state = 0;
		}
		
		//stop our video when it gets to the end
		if(VID2.getPosition() > 0.95){
			VID2.setSpeed(0);
		}
	
	}
	
	VID.idleMovie();
	VID2.idleMovie();
	
}

//--------------------------------------------------------------
void testApp::draw(){

	if(full == 1){ ofSetColor(0xFFFFFF); 	VID.draw(0, 0, 640, 480); return ;}
	if(full == 2){ ofSetColor(0xFFFFFF); 	VID2.draw(0, 0, 640, 480); return ;}

	ofSetColor(0x00DD22);

	VID.draw(18, 230, 160, 120);
	VID2.draw(200, 230, 160, 120);
		
	string str2 = message+"\n";
	
	string str = "";
	
	str += "number is "+ofToString(valueIn)+"\n";
	str += "smoothed is "+ofToString(smoothedValue, 2)+"\n";
	str += "normalized is "+ofToString(normalizedValue, 7)+"\n";
	
	for(int i = 0; i < 640; i++){
		ofLine(i, 480, i, 480 - values[i] * 100); 
	}	
	
	
	if(smoothedValue > 900){
		ofSetColor(0x00DD22);
		ofRect(380,230, 32, 32);
		ofSetColor(0xFFFF00);		
		ofRect(382,232, 28, 28);
		
		ofSetColor(0x00DD22);		
		str += "state is high\n";
	}
	else if(smoothedValue < 100){
		ofSetColor(0x00DD22);
		ofRect(380,230, 32, 32);
		ofSetColor(0x005508);		
		ofRect(382,232, 28, 28);
		
		ofSetColor(0x00DD22);		
		str += "state is low\n";
	}
	else{
		ofSetColor(0x00DD22);
		ofRect(382,230, 32, 32);
		
		ofSetColor(0x00DD22);
		str += "state is middle\n";
	}
	
	TTF.drawString(str2, 10, 35);	
	TTF.drawString(str, 10, 80);
	
	if(!isSetup){
		ofSetColor(0xFF0000);
		TTF.drawString("can't connect to device! - try different device number ",  10, 465);
	}
	
}


//--------------------------------------------------------------
void testApp::keyPressed  (int key){ 
	if(key == 'f') full ++;
	if(full >= 3) full = 0;	
}

//--------------------------------------------------------------
void testApp::mouseMoved(int x, int y ){
	
}

//--------------------------------------------------------------
void testApp::mouseDragged(int x, int y, int button){
	
}

//--------------------------------------------------------------
void testApp::mousePressed(int x, int y, int button){

}

//--------------------------------------------------------------
void testApp::mouseReleased(){
}
